﻿using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Logging;
using System;
using System.Threading.Tasks;

namespace TestProject
{
    /// <summary>
    /// 프로그램
    /// </summary>
    class Program
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Private

        #region 프로그램 시작하기 - Main()

        /// <summary>
        /// 프로그램 시작하기
        /// </summary>
        /// <returns>처리 결과 태스크</returns>
        private static async Task<int> Main()
        {
            IHostBuilder builder = new HostBuilder()
                .ConfigureServices
                (
                    (hostContext, services) =>
                    {
                        services.AddHttpClient();

                        services.AddTransient<ITestService, TestService>();
                    }
                )
                .UseConsoleLifetime();

            IHost host = builder.Build();

            using(IServiceScope serviceScope = host.Services.CreateScope())
            {
                IServiceProvider serviceProvider = serviceScope.ServiceProvider;

                try
                {
                    ITestService service = serviceProvider.GetRequiredService<ITestService>();

                    string pageContent = await service.GetPage();

                    Console.WriteLine(pageContent.Substring(0, 500));
                }
                catch(Exception exception)
                {
                    ILogger<Program> logger = serviceProvider.GetRequiredService<ILogger<Program>>();

                    logger.LogError(exception, "An error occurred.");
                }
            }

            return 0;
        }

        #endregion
    }
}