﻿using System.Net.Http;
using System.Text;
using System.Threading.Tasks;

namespace TestProject
{
    /// <summary>
    /// 테스트 서비스
    /// </summary>
    public class TestService : ITestService
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// HTTP 클라이언트 팩토리
        /// </summary>
        private readonly IHttpClientFactory factory;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - TestService(factory)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="factory">HTTP 클라이언트 팩토리</param>
        public TestService(IHttpClientFactory factory)
        {
            this.factory = factory;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 페이지 구하기 - GetPage()

        /// <summary>
        /// 페이지 구하기
        /// </summary>
        /// <returns>페이지</returns>
        public async Task<string> GetPage()
        {
            HttpRequestMessage requestMessage = new HttpRequestMessage
            (
                HttpMethod.Get,
                "https://www.bbc.co.uk/programmes/b006q2x0"
            );

            HttpClient client = this.factory.CreateClient();

            HttpResponseMessage responseMessage = await client.SendAsync(requestMessage);

            if(responseMessage.IsSuccessStatusCode)
            {
                byte[] byteArray = await responseMessage.Content.ReadAsByteArrayAsync();

                return Encoding.UTF8.GetString(byteArray, 0, byteArray.Length);
            }
            else
            {
                return $"상태 코드 : {responseMessage.StatusCode}";
            }
        }

        #endregion
    }
}